# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_kwctl_global_optspecs
	string join \n v/verbose no-color h/help V/version
end

function __fish_kwctl_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_kwctl_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_kwctl_using_subcommand
	set -l cmd (__fish_kwctl_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c kwctl -n "__fish_kwctl_needs_command" -s v -l verbose -d 'Increase verbosity'
complete -c kwctl -n "__fish_kwctl_needs_command" -l no-color -d 'Disable colorful output'
complete -c kwctl -n "__fish_kwctl_needs_command" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_needs_command" -s V -l version -d 'Print version'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "annotate" -d 'Add Kubewarden metadata to a WebAssembly module'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "bench" -d 'Benchmarks a Kubewarden policy'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "completions" -d 'Generate shell completions'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "digest" -d 'Fetch digest from the OCI manifest of a policy'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "info" -d 'Display system information'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "inspect" -d 'Inspect Kubewarden policy'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "load" -d 'load policies from a tar.gz file'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "policies" -d 'Lists all downloaded policies'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "pull" -d 'Pulls a Kubewarden policy from a given URI'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "push" -d 'Pushes a Kubewarden policy to an OCI registry'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "rm" -d 'Removes a Kubewarden policy from the store'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "run" -d 'Runs a Kubewarden policy from a given URI'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "save" -d 'save policies to a tar.gz file'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "scaffold" -d 'Scaffold a Kubernetes resource or configuration file'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "verify" -d 'Verify a Kubewarden policy from a given URI using Sigstore'
complete -c kwctl -n "__fish_kwctl_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c kwctl -n "__fish_kwctl_using_subcommand annotate" -s m -l metadata-path -d 'File containing the metadata' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand annotate" -s o -l output-path -d 'Output file' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand annotate" -s u -l usage-path -d 'File containing the usage information of the policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand annotate" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l cert-email -d 'Expected email in Fulcio certificate' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l cert-oidc-issuer -d 'Expected OIDC issuer in Fulcio certificates' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l dump-results-to-disk -d 'Puts results in target/tiny-bench/label/.. if target can be found. used for comparing previous runs' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -s e -l execution-mode -d 'The runtime to use to execute this policy' -r -f -a "{opa\t'',gatekeeper\t'',kubewarden\t'',wasi\t''}"
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l fulcio-cert-path -d 'Path to the Fulcio certificate. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l github-owner -d 'GitHub owner expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l github-repo -d 'GitHub repository expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l measurement-time -d 'How long the bench ‘should’ run, num_samples is prioritized so benching will take longer to be able to collect num_samples if the code to be benched is slower than this time limit allowed' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l num-resamples -d 'How many resamples should be done' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l num-samples -d 'How many resamples should be done. Recommended at least 50, above 100 doesn’t seem to yield a significantly different result' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l record-host-capabilities-interactions -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l rekor-public-key-path -d 'Path to the Rekor public key' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l replay-host-capabilities-interactions -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -s r -l request-path -d 'File containing the Kubernetes admission request object in JSON format' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l settings-json -d 'JSON string containing the settings for this policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -s s -l settings-path -d 'File containing the settings for this policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -s a -l verification-annotation -d 'Annotation in key=value format. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l verification-config-path -d 'YAML file holding verification config information (signatures, public keys...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -s k -l verification-key -d 'Path to key used to verify the policy. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l warm-up-time -d 'How long the bench should warm up' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l allow-context-aware -d 'Grant access to the Kubernetes resources defined inside of the policy\'s `contextAwareResources` section. Warning: review the list of resources carefully to avoid abuses. Disabled by default'
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l disable-wasmtime-cache -d 'Turn off usage of wasmtime cache'
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -l raw -d 'Validate a raw request'
complete -c kwctl -n "__fish_kwctl_using_subcommand bench" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c kwctl -n "__fish_kwctl_using_subcommand completions" -s s -l shell -d 'Shell type' -r -f -a "{bash\t'',elvish\t'',fish\t'',powershell\t'',zsh\t''}"
complete -c kwctl -n "__fish_kwctl_using_subcommand completions" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand digest" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand digest" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand digest" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand info" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand inspect" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand inspect" -s o -l output -d 'Output format' -r -f -a "{yaml\t''}"
complete -c kwctl -n "__fish_kwctl_using_subcommand inspect" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand inspect" -l show-signatures -d 'Show sigstore signatures'
complete -c kwctl -n "__fish_kwctl_using_subcommand inspect" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand load" -l input -d 'load policies from tarball' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand load" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand policies" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l cert-email -d 'Expected email in Fulcio certificate' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l cert-oidc-issuer -d 'Expected OIDC issuer in Fulcio certificates' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l fulcio-cert-path -d 'Path to the Fulcio certificate. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l github-owner -d 'GitHub owner expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l github-repo -d 'GitHub repository expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -s o -l output-path -d 'Output file. If not provided will be downloaded to the Kubewarden store' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l rekor-public-key-path -d 'Path to the Rekor public key. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -s a -l verification-annotation -d 'Annotation in key=value format. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -l verification-config-path -d 'YAML file holding verification config information (signatures, public keys...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -s k -l verification-key -d 'Path to key used to verify the policy. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand pull" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand push" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand push" -s f -l force -d 'Push also a policy that is not annotated' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand push" -s o -l output -d 'Output format' -r -f -a "{text\t'',json\t''}"
complete -c kwctl -n "__fish_kwctl_using_subcommand push" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand push" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand rm" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l cert-email -d 'Expected email in Fulcio certificate' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l cert-oidc-issuer -d 'Expected OIDC issuer in Fulcio certificates' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -s e -l execution-mode -d 'The runtime to use to execute this policy' -r -f -a "{opa\t'',gatekeeper\t'',kubewarden\t'',wasi\t''}"
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l fulcio-cert-path -d 'Path to the Fulcio certificate. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l github-owner -d 'GitHub owner expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l github-repo -d 'GitHub repository expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l record-host-capabilities-interactions -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l rekor-public-key-path -d 'Path to the Rekor public key' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l replay-host-capabilities-interactions -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -s r -l request-path -d 'File containing the Kubernetes admission request object in JSON format' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l settings-json -d 'JSON string containing the settings for this policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -s s -l settings-path -d 'File containing the settings for this policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -s a -l verification-annotation -d 'Annotation in key=value format. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l verification-config-path -d 'YAML file holding verification config information (signatures, public keys...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -s k -l verification-key -d 'Path to key used to verify the policy. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l allow-context-aware -d 'Grant access to the Kubernetes resources defined inside of the policy\'s `contextAwareResources` section. Warning: review the list of resources carefully to avoid abuses. Disabled by default'
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l disable-wasmtime-cache -d 'Turn off usage of wasmtime cache'
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -l raw -d 'Validate a raw request'
complete -c kwctl -n "__fish_kwctl_using_subcommand run" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c kwctl -n "__fish_kwctl_using_subcommand save" -s o -l output -d 'path where the file will be stored' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand save" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and not __fish_seen_subcommand_from admission-request artifacthub manifest vap verification-config help" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and not __fish_seen_subcommand_from admission-request artifacthub manifest vap verification-config help" -f -a "admission-request" -d 'Scaffold an AdmissionRequest object'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and not __fish_seen_subcommand_from admission-request artifacthub manifest vap verification-config help" -f -a "artifacthub" -d 'Output an artifacthub-pkg.yml file from a metadata.yml file'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and not __fish_seen_subcommand_from admission-request artifacthub manifest vap verification-config help" -f -a "manifest" -d 'Output a Kubernetes resource manifest'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and not __fish_seen_subcommand_from admission-request artifacthub manifest vap verification-config help" -f -a "vap" -d 'Convert a Kubernetes `ValidatingAdmissionPolicy` into a Kubewarden `ClusterAdmissionPolicy`'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and not __fish_seen_subcommand_from admission-request artifacthub manifest vap verification-config help" -f -a "verification-config" -d 'Output a default Sigstore verification configuration file'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and not __fish_seen_subcommand_from admission-request artifacthub manifest vap verification-config help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from admission-request" -l object -d 'The file containing the new object being admitted' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from admission-request" -l old-object -d 'The file containing the existing object' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from admission-request" -s o -l operation -d 'Kubewarden Custom Resource type' -r -f -a "{CREATE\t''}"
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from admission-request" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from artifacthub" -s m -l metadata-path -d 'File containing the metadata of the policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from artifacthub" -s o -l output -d 'Path where the artifact-pkg.yml file will be stored' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from artifacthub" -s q -l questions-path -d 'File containing the questions-ui content of the policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from artifacthub" -s v -l version -d 'Semver version of the policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from artifacthub" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l cert-email -d 'Expected email in Fulcio certificate' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l cert-oidc-issuer -d 'Expected OIDC issuer in Fulcio certificates' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l fulcio-cert-path -d 'Path to the Fulcio certificate. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l github-owner -d 'GitHub owner expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l github-repo -d 'GitHub repository expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l rekor-public-key-path -d 'Path to the Rekor public key. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l settings-json -d 'JSON string containing the settings for this policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -s s -l settings-path -d 'File containing the settings for this policy' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l title -d 'Policy title' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -s t -l type -d 'Kubewarden Custom Resource type' -r -f -a "{ClusterAdmissionPolicy\t'',AdmissionPolicy\t''}"
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -s a -l verification-annotation -d 'Annotation in key=value format. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l verification-config-path -d 'YAML file holding verification config information (signatures, public keys...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -s k -l verification-key -d 'Path to key used to verify the policy. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -l allow-context-aware -d 'Uses the policy metadata to define which Kubernetes resources can be accessed by the policy. Warning: review the list of resources carefully to avoid abuses. Disabled by default'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from manifest" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from vap" -s b -l binding -d 'The file containining the ValidatingAdmissionPolicyBinding definition' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from vap" -l cel-policy -d 'The CEL policy module to use' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from vap" -s p -l policy -d 'The file containining the ValidatingAdmissionPolicy definition' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from vap" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from verification-config" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from help" -f -a "admission-request" -d 'Scaffold an AdmissionRequest object'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from help" -f -a "artifacthub" -d 'Output an artifacthub-pkg.yml file from a metadata.yml file'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from help" -f -a "manifest" -d 'Output a Kubernetes resource manifest'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from help" -f -a "vap" -d 'Convert a Kubernetes `ValidatingAdmissionPolicy` into a Kubewarden `ClusterAdmissionPolicy`'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from help" -f -a "verification-config" -d 'Output a default Sigstore verification configuration file'
complete -c kwctl -n "__fish_kwctl_using_subcommand scaffold; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l cert-email -d 'Expected email in Fulcio certificate' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l cert-oidc-issuer -d 'Expected OIDC issuer in Fulcio certificates' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l docker-config-json-path -d 'Path to a directory containing the Docker \'config.json\' file. Can be used to indicate registry authentication details' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l fulcio-cert-path -d 'Path to the Fulcio certificate. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l github-owner -d 'GitHub owner expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l github-repo -d 'GitHub repository expected in the certificates generated in CD pipelines' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l rekor-public-key-path -d 'Path to the Rekor public key' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l sources-path -d 'YAML file holding source information (https, registry insecure hosts, custom CA\'s...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -s a -l verification-annotation -d 'Annotation in key=value format. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -l verification-config-path -d 'YAML file holding verification config information (signatures, public keys...)' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -s k -l verification-key -d 'Path to key used to verify the policy. Can be repeated multiple times' -r
complete -c kwctl -n "__fish_kwctl_using_subcommand verify" -s h -l help -d 'Print help'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "annotate" -d 'Add Kubewarden metadata to a WebAssembly module'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "bench" -d 'Benchmarks a Kubewarden policy'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "completions" -d 'Generate shell completions'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "digest" -d 'Fetch digest from the OCI manifest of a policy'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "info" -d 'Display system information'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "inspect" -d 'Inspect Kubewarden policy'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "load" -d 'load policies from a tar.gz file'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "policies" -d 'Lists all downloaded policies'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "pull" -d 'Pulls a Kubewarden policy from a given URI'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "push" -d 'Pushes a Kubewarden policy to an OCI registry'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "rm" -d 'Removes a Kubewarden policy from the store'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "run" -d 'Runs a Kubewarden policy from a given URI'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "save" -d 'save policies to a tar.gz file'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "scaffold" -d 'Scaffold a Kubernetes resource or configuration file'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "verify" -d 'Verify a Kubewarden policy from a given URI using Sigstore'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and not __fish_seen_subcommand_from annotate bench completions digest info inspect load policies pull push rm run save scaffold verify help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and __fish_seen_subcommand_from scaffold" -f -a "admission-request" -d 'Scaffold an AdmissionRequest object'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and __fish_seen_subcommand_from scaffold" -f -a "artifacthub" -d 'Output an artifacthub-pkg.yml file from a metadata.yml file'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and __fish_seen_subcommand_from scaffold" -f -a "manifest" -d 'Output a Kubernetes resource manifest'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and __fish_seen_subcommand_from scaffold" -f -a "vap" -d 'Convert a Kubernetes `ValidatingAdmissionPolicy` into a Kubewarden `ClusterAdmissionPolicy`'
complete -c kwctl -n "__fish_kwctl_using_subcommand help; and __fish_seen_subcommand_from scaffold" -f -a "verification-config" -d 'Output a default Sigstore verification configuration file'
